# CESR Composable Event Streaming Representation

Python implementation of CESR Protocol

Supports composable text and binary encoding

Supports pipelined streaming

Supports interleaved JSON, CBOR, MGPK, and native CESR
